# Axidence

[![Test package](https://github.com/dachengx/axidence/actions/workflows/pytest.yml/badge.svg?branch=main)](https://github.com/dachengx/axidence/actions/workflows/pytest.yml)
[![Coverage Status](https://coveralls.io/repos/github/dachengx/axidence/badge.svg?branch=main&kill_cache=1)](https://coveralls.io/github/dachengx/axidence?branch=main&kill_cache=1)
[![PyPI version shields.io](https://img.shields.io/pypi/v/axidence.svg)](https://pypi.python.org/pypi/axidence/)
[![Documentation Status](https://readthedocs.org/projects/axidence/badge/?version=latest)](https://axidence.readthedocs.io/en/latest/?badge=latest)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/dachengx/axidence/main.svg)](https://results.pre-commit.ci/latest/github/dachengx/axidence/main)

Axidence is a stax-based data-driven accidental coincidence background simulation framework. It can also perform the peak-level salting to calculate the features related to ambient environment.

# Installation
```
cd axidence
pip install ./ --user
```
